@@ -8,9 +8,6 @@
 **  
 */
 
-const char * Revision_io_c =
-   "io.c, V4.0";
-
 /* Try to use as much of the GNU C library as possible: */
 #define _GNU_SOURCE
 
@@ -271,7 +268,7 @@ Obj FuncIO_WaitPid(Obj self,Obj pid,Obj wait)
   signal(SIGCHLD,IO_SIGCHLDHandler);
   return tmp;
 } 
-#endif 
+#endif
 
 Obj FuncIO_open(Obj self,Obj path,Obj flags,Obj mode)
 {
@@ -2056,9 +2053,11 @@ static StructGVarFunc GVarFuncs [] = {
     "io.c:IO_select" },
 #endif
 
+#if defined(HAVE_SIGACTION) || defined(HAVE_SIGNAL)
   { "IO_WaitPid", 2, "pid, wait",
     FuncIO_WaitPid, 
     "io.c:IO_WaitPid" },
+#endif
 
 #ifdef HAVE_FORK
   { "IO_fork", 0, "",
@@ -3070,14 +3069,12 @@ static StructInitInfo module = {
 #ifndef IOSTATIC
 StructInitInfo * Init__Dynamic ( void )
 {
-  module.revision_c = Revision_io_c;
   return &module;
 }
 #endif
 
 StructInitInfo * Init__io ( void )
 {
-  module.revision_c = Revision_io_c;
   return &module;
 }
 
